@@ -17,13 +17,13 @@ use vars qw ($Debug $VERSION
 	     $Bit_Access_Regexp %Ignore_Keywords);
 use base qw (SystemC::Vregs::Subclass);	# In Vregs:: so we can get Vregs->warn()
 
-$VERSION = '1.462';
+$VERSION = '1.463';
 
 ######################################################################
 #### Constants
 
 # Regexp matching valid bit access
-$Bit_Access_Regexp = '^(RS?|)(WS?|W1CS?|)L?'."\$";
+$Bit_Access_Regexp = '^(RS?|)(WS?|W1CS?|H|)L?'."\$";
 
 # Loaded by user programs to prevent keyword warnings
 %Ignore_Keywords = ();
@@ -1398,7 +1398,8 @@ L<http://www.veripool.org/vregs>.  /www.veripool.org/>.
 
 Copyright 2001-2009 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
-Lesser General Public License or the Perl Artistic License.
+Lesser General Public License Version 3 or the Perl Artistic License
+Version 2.0.
 
 =head1 AUTHORS
 
